@@ -2,14 +2,14 @@ import importlib
 import inspect
 import yaml
 
-from typing import Callable
+from typing import Callable, Tuple
 
 class YAMLDumper(yaml.Dumper):
 
     def increase_indent(self, flow=False, indentless=False):
         return super(YAMLDumper, self).increase_indent(flow, False)
 
-def get_class(module_name: str, module_path: str) -> tuple[str, Callable]:
+def get_class(module_name: str, module_path: str) -> Tuple[str, Callable]:
     """Retrieves the correct class name of a module"""
 
     # Import the module
